@@ -58,11 +58,18 @@ def list_collectors(ctx, active_only):
 
 @collectors.command(help=f'Add a collector record to the account. {ADD_DC_VERBIAGE}', name='add')
 @click.pass_obj
+@click.option('--template-provider', required=False, default='cloudformation', show_default=True,
+              help='Template IaC provider')
+@click.option('--template-variant', required=False, default='hephaestus', show_default=True,
+              help='Template variant')
 @click.option('--no-prompt', required=False, default=False, show_default=True, is_flag=True,
               help='Skip prompt for launching browser (Auto no).')
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_collector(ctx, no_prompt):
-    CollectorManagementService(config=ctx['config']).add_collector(no_prompt=no_prompt)
+def add_collector(ctx, no_prompt, template_provider, template_variant):
+    CollectorManagementService(config=ctx['config']).add_collector(
+        template_provider=template_provider,
+        template_variant=template_variant,
+        no_prompt=no_prompt)
 
 
 @collectors.command(help='Get link to the latest template. For initial deployment or manually upgrading.')
