@@ -1,3 +1,5 @@
+from typing import List
+
 import click
 import click_config_file
 
@@ -51,15 +53,27 @@ PASSWORD_VERBIAGE = f'If you prefer a prompt (with hidden input) enter {settings
 RESOURCE_VERBIAGE = 'This can be helpful if the resources are in different accounts'
 CONNECTION_ID_VERBIAGE = 'ID for the connection.'
 
+
 # Options shared across commands
-ROLE_OPTIONS = [
-    click.option('--role', help='Assumable role ARN to use for accessing AWS resources.', required=False),
-    click.option('--external-id', help='An external id, per assumable role conditions.', required=False),
+def role_options(required: bool = True) -> List:
+    return [
+        click.option('--role', help='Assumable role ARN to use for accessing AWS resources.', required=required),
+        click.option('--external-id', help='An external id, per assumable role conditions.', required=False),
+    ]
+
+
+# Name is used for the creation of the warehouse
+WAREHOUSE_CREATE_OPTIONS = [
+    click.option('--name', help='Friendly name for the created warehouse. Name must be unique.', required=False)
+]
+# Name is used to identify the warehouse that will contain the connection.
+WAREHOUSE_SELECT_OPTIONS = [
+    click.option('--name', help='Friendly name of the warehouse which the connection will belong to.', required=False)
 ]
 S3_OPTIONS = [
     click.option('--bucket', help='S3 Bucket where query logs are contained.', required=True),
     click.option('--prefix', help='Path to query logs.', required=True),
-    *ROLE_OPTIONS
+    *role_options(required=False)
 ]
 EVENT_OPTIONS = [
     click.option('--enable/--disable', 'toggle', help='Enable or disable events. Enables if not specified.',
@@ -178,14 +192,17 @@ def integrations():
               default=False, show_default=True)
 @click.option('--catalog', help='Presto catalog name. For using multiple hive clusters with Presto. '
                                 'Uses \'hive\' if not specified.', required=False)
+@add_common_options(WAREHOUSE_CREATE_OPTIONS)
 @add_common_options(DATABASE_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_hive_metastore(ctx, database, **kwargs):
+def add_hive_metastore(ctx, database, name, **kwargs):
     """
     Onboard a hive metastore connection (MySQL)
     """
-    HiveOnboardingService(config=ctx['config']).onboard_hive_mysql(dbName=database, **kwargs)
+    HiveOnboardingService(config=ctx['config']).onboard_hive_mysql(
+        dbName=database, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help=f'Setup a Presto SQL integration. {SQL_VERBIAGE}.')
@@ -203,15 +220,18 @@ def add_hive_metastore(ctx, database, **kwargs):
 @click.option('--cert-s3', help='Object path (key) to a certificate already uploaded to the collector.',
               required=False, cls=AdvancedOptions, mutually_exclusive_options=['cert_file'])
 @click.option('--skip-cert-verification', help='Skip SSL certificate verification.', required=False, is_flag=True)
+@add_common_options(WAREHOUSE_SELECT_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_presto(ctx, password, **kwargs):
+def add_presto(ctx, password, name, **kwargs):
     """
     Onboard a presto sql connection
     """
     if not password:
         password = None  # make explicitly null if not set. Prompts can't be None
-    PrestoOnboardingService(config=ctx['config']).onboard_presto_sql(password=password, **kwargs)
+    PrestoOnboardingService(config=ctx['config']).onboard_presto_sql(
+        password=password, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help=f'Setup a Hive SQL integration. {SQL_VERBIAGE}.')
@@ -222,10 +242,13 @@ def add_presto(ctx, password, **kwargs):
 @click.option('--user', help='Username with access to hive.', required=True)
 @click.option('--auth-mode', help='Hive authentication mode.', required=False, default='SASL',
               type=click.Choice(['SASL', 'NOSASL']), show_default=True)
+@add_common_options(WAREHOUSE_SELECT_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_hive(ctx, user, **kwargs):
-    HiveOnboardingService(config=ctx['config']).onboard_hive_sql(username=user, **kwargs)
+def add_hive(ctx, user, name, **kwargs):
+    HiveOnboardingService(config=ctx['config']).onboard_hive_sql(
+        username=user, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help=f'Setup a Presto logs integration (S3). {QL_VERBIAGE}.')
@@ -233,7 +256,7 @@ def add_hive(ctx, user, **kwargs):
 @add_common_options(S3_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_presto_logs(ctx, role, **kwargs):
+def add_presto_logs(ctx, role, **kwargs):  # DEPRECATED
     """
     Onboard a presto logs (s3) connection
     """
@@ -245,7 +268,7 @@ def add_presto_logs(ctx, role, **kwargs):
 @add_common_options(S3_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_hive_logs(ctx, role, **kwargs):
+def add_hive_logs(ctx, role, **kwargs):  # DEPRECATED
     """
     Onboard a hive emr (s3) connection
     """
@@ -255,14 +278,17 @@ def add_hive_logs(ctx, role, **kwargs):
 @integrations.command(help=f'Setup a Glue integration. {METADATA_VERBIAGE}.')
 @click.pass_obj
 @click.option('--region', help=f'Glue catalog region. {REGION_VERBIAGE}.', required=False)
-@add_common_options(ROLE_OPTIONS)
+@add_common_options(role_options())
+@add_common_options(WAREHOUSE_CREATE_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_glue(ctx, role, region, **kwargs):
+def add_glue(ctx, role, region, name, **kwargs):
     """
     Onboard a glue connection
     """
-    GlueAthenaOnboardingService(config=ctx['config']).onboard_glue(assumable_role=role, aws_region=region, **kwargs)
+    GlueAthenaOnboardingService(config=ctx['config']).onboard_glue(
+        assumable_role=role, aws_region=region, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help='Setup an Athena integration. For query logs and health queries.')
@@ -272,14 +298,17 @@ def add_glue(ctx, role, region, **kwargs):
               help='Workbook for running queries and retrieving logs. If not specified the primary is used.',
               required=False)
 @click.option('--region', help=f'Athena cluster region. {REGION_VERBIAGE}.', required=False)
-@add_common_options(ROLE_OPTIONS)
+@add_common_options(WAREHOUSE_SELECT_OPTIONS)
+@add_common_options(role_options())
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_athena(ctx, role, region, **kwargs):
+def add_athena(ctx, role, region, name, **kwargs):
     """
     Onboard an athena connection
     """
-    GlueAthenaOnboardingService(config=ctx['config']).onboard_athena(assumable_role=role, aws_region=region, **kwargs)
+    GlueAthenaOnboardingService(config=ctx['config']).onboard_athena(
+        assumable_role=role, aws_region=region, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help=f'Setup a thrift binary Spark integration. {SQL_VERBIAGE}.')
@@ -290,13 +319,16 @@ def add_athena(ctx, role, region, **kwargs):
 @click.option('--user', help='Username with access to spark.', required=True)
 @click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}.', required=True,
               cls=AdvancedOptions, prompt_if_requested=True)
+@add_common_options(WAREHOUSE_SELECT_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_spark_binary_mode(ctx, user, **kwargs):
+def add_spark_binary_mode(ctx, user, name, **kwargs):
     """
     Onboard a spark connection, thrift binary mode
     """
-    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_BINARY_MODE_CONFIG_TYPE, username=user, **kwargs)
+    SparkOnboardingService(config=ctx['config']).onboard_spark(
+        SPARK_BINARY_MODE_CONFIG_TYPE, username=user, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help=f'Setup a thrift HTTP Spark integration. {SQL_VERBIAGE}.')
@@ -305,13 +337,16 @@ def add_spark_binary_mode(ctx, user, **kwargs):
 @click.option('--user', help='Username with access to spark.', required=True)
 @click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}.', required=True,
               cls=AdvancedOptions, prompt_if_requested=True)
+@add_common_options(WAREHOUSE_SELECT_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_spark_http_mode(ctx, user, **kwargs):
+def add_spark_http_mode(ctx, user, name, **kwargs):
     """
     Onboard a spark connection, thrift http mode
     """
-    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_HTTP_MODE_CONFIG_TYPE, username=user, **kwargs)
+    SparkOnboardingService(config=ctx['config']).onboard_spark(
+        SPARK_HTTP_MODE_CONFIG_TYPE, username=user, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help=f'Setup a Spark integration for Databricks. {SQL_VERBIAGE}.')
@@ -319,26 +354,31 @@ def add_spark_http_mode(ctx, user, **kwargs):
 @add_common_options(DATABRICKS_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_spark_databricks(ctx, **kwargs):
+def add_spark_databricks(ctx, name, **kwargs):
     """
     Onboard a spark connection, databricks
     """
-    SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_DATABRICKS_CONFIG_TYPE, **kwargs)
+    SparkOnboardingService(config=ctx['config']).onboard_spark(
+        SPARK_DATABRICKS_CONFIG_TYPE, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help='Setup a Databricks metastore integration. For metadata and health queries.')
 @click.pass_obj
+@add_common_options(WAREHOUSE_CREATE_OPTIONS)
 @add_common_options(DATABRICKS_OPTIONS)
 @add_common_options(DATABRICKS_DATA_COLLECTOR_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_databricks_metastore(ctx, **kwargs):
+def add_databricks_metastore(ctx, name, **kwargs):
     """
     Onboard a databricks metastore
     """
     DatabricksOnboardingService(
         config=ctx['config'], mc_client=create_mc_client(ctx)
-    ).onboard_databricks_metastore(connection_type=DATABRICKS_METASTORE_CONNECTION_TYPE, **kwargs)
+    ).onboard_databricks_metastore(
+        connection_type=DATABRICKS_METASTORE_CONNECTION_TYPE, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help='Setup a Databricks Delta integration. For metadata queries on delta tables when using an external metastore in databricks.')
@@ -346,20 +386,23 @@ def add_databricks_metastore(ctx, **kwargs):
 @add_common_options(DATABRICKS_OPTIONS)
 @add_common_options(DATABRICKS_DATA_COLLECTOR_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+@add_common_options(WAREHOUSE_SELECT_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def add_databricks_delta(ctx, **kwargs):
+def add_databricks_delta(ctx, name, **kwargs):
     """
     Onboard a databricks delta service
     """
     DatabricksOnboardingService(
         config=ctx['config'], mc_client=create_mc_client(ctx)
-    ).onboard_databricks_metastore(connection_type=DATABRICKS_DELTA_CONNECTION_TYPE, **kwargs)
+    ).onboard_databricks_metastore(
+        connection_type=DATABRICKS_DELTA_CONNECTION_TYPE, warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help=f'Setup a Redshift integration. {WAREHOUSE_VERBIAGE}.')
 @click.pass_obj
 @click.option('--port', help='HTTP port.', default=5439, type=click.INT, show_default=True)
-@click.option('--name', help='Friendly name for the warehouse.', required=True)
+@add_common_options(WAREHOUSE_CREATE_OPTIONS)
 @add_common_options(DATABASE_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @add_common_options(NETWORK_OPTIONS)
@@ -378,7 +421,7 @@ def add_redshift(ctx, database, name, **kwargs):
 @click.option('--warehouse', help='Name of the warehouse for the user.', required=True)
 @click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}.', required=True,
               cls=AdvancedOptions, prompt_if_requested=True)
-@click.option('--name', help='Friendly name for the warehouse.', required=True)
+@add_common_options(WAREHOUSE_CREATE_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def add_snowflake(ctx, name, **kwargs):
@@ -391,7 +434,7 @@ def add_snowflake(ctx, name, **kwargs):
 @integrations.command(help=f'Setup a BigQuery integration. {WAREHOUSE_VERBIAGE}.')
 @click.pass_obj
 @click.option('--key-file', help='JSON Key file.', type=click.Path(exists=True), required=True)
-@click.option('--name', help='Friendly name for the warehouse.', required=True)
+@add_common_options(WAREHOUSE_CREATE_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def add_bigquery(ctx, key_file, name, **kwargs):
@@ -420,8 +463,8 @@ def add_bigquery(ctx, key_file, name, **kwargs):
     default=SECRETS_MANAGER_CREDENTIAL_MECHANISM,
 )
 @click.option('--key', help='Identifier for credentials within self-hosting mechanism.', required=True)
-@click.option('--name', help='Friendly name for the warehouse. Required for warehouses.', required=False)
-@add_common_options(ROLE_OPTIONS)
+@click.option('--name', help='Friendly name for the warehouse.', required=False)
+@add_common_options(role_options(required=False))
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def add_self_hosted_credentials(ctx, mechanism, key, role, name, **kwargs):
@@ -440,7 +483,7 @@ def add_self_hosted_credentials(ctx, mechanism, key, role, name, **kwargs):
 @integrations.command(help='Toggle S3 events for Airflow task logs.')
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
-@add_common_options(ROLE_OPTIONS)
+@add_common_options(role_options())
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def toggle_airflow_log_events(ctx, toggle, role, **kwargs):
     """
@@ -475,7 +518,7 @@ def toggle_metadata_events(ctx, toggle, **kwargs):
 @integrations.command(help=f'Toggle S3 query log events. {EVENT_VERBIAGE}.')
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
-@add_common_options(ROLE_OPTIONS)
+@add_common_options(role_options())
 @click.option('--connection-type', help='Type of the integration.',
               type=click.Choice([HIVE_S3_CONNECTION_TYPE, PRESTO_S3_CONNECTION_TYPE], case_sensitive=True),
               required=False)
@@ -566,15 +609,15 @@ def add_looker_git(ctx, **kwargs):
 @click.option('--dbt-cloud-api-token', 'dbt_cloud_api_token', help=f'dbt Cloud API token. {PASSWORD_VERBIAGE}.',
               required=True, cls=AdvancedOptions, prompt_if_requested=True)
 @click.option('--dbt-cloud-account-id', 'dbt_cloud_account_id', help='dbt Cloud Account ID.', required=True)
-@click.option('--connection-id', 'connection_id', required=False,
-              help='ID of warehouse connection to link with dbt Cloud. '
-                   'Required if there are multiple warehouse connections present.')
+@add_common_options(WAREHOUSE_SELECT_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
-def add_dbt_cloud(ctx, **kwargs):
+def add_dbt_cloud(ctx, name, **kwargs):
     """
-    Onboard a looker metadata connection
+    Onboard a dbt cloud connection
     """
-    DbtCloudOnboardingService(config=ctx['config']).onboard_dbt_cloud(**kwargs)
+    DbtCloudOnboardingService(config=ctx['config']).onboard_dbt_cloud(
+        warehouseName=name, **kwargs
+    )
 
 
 @integrations.command(help='List all active connections.', name='list')
