@@ -44,6 +44,18 @@ DBT_CLOUD_CONNECTION_TYPE = 'dbt-cloud'
 DATABRICKS_METASTORE_CONNECTION_TYPE = 'databricks-metastore'
 DATABRICKS_DELTA_CONNECTION_TYPE = 'databricks-delta'
 
+METASTORE_CONNECTION_TYPES = (
+    HIVE_MYSQL_CONNECTION_TYPE, GLUE_CONNECTION_TYPE, DATABRICKS_METASTORE_CONNECTION_TYPE
+)
+
+# Every warehouse must have one and only one of these.
+MAIN_CONNECTION_TYPES = frozenset([
+    BQ_CONNECTION_TYPE,
+    REDSHIFT_CONNECTION_TYPE,
+    SNOWFLAKE_CONNECTION_TYPE,
+    *METASTORE_CONNECTION_TYPES
+])
+
 # Available warehouse types
 DATA_LAKE_WAREHOUSE_TYPE = 'data-lake'
 REDSHIFT_WAREHOUSE_TYPE = REDSHIFT_CONNECTION_TYPE
@@ -56,6 +68,11 @@ CONNECTION_TO_WAREHOUSE_TYPE_MAP = {
     SNOWFLAKE_CONNECTION_TYPE: SNOWFLAKE_WAREHOUSE_TYPE,
 }
 
+# Available BI types
+LOOKER_BI_TYPE = 'looker'
+TABLEAU_BI_TYPE = 'tableau'
+POWER_BI_BI_TYPE = 'power-bi'
+
 # Available credential self-hosting mechanisms
 SECRETS_MANAGER_CREDENTIAL_MECHANISM = 'secretsmanager'
 SELF_HOSTING_MECHANISMS = [SECRETS_MANAGER_CREDENTIAL_MECHANISM]
