@@ -28,7 +28,9 @@ class BaseOnboardingTest(TestCase):
 
         self._user_service_mock.collectors = _SAMPLE_USER_RESPONSE['getUser']['account']['dataCollectors']
         self._user_service_mock.active_collector = self._user_service_mock.collectors[0]
-        self._user_service_mock.warehouses = [{'uuid': _SAMPLE_DW_ID, 'connectionType': 'data-lake'}]
+        self._user_service_mock.warehouses = [
+            {'uuid': _SAMPLE_DW_ID, 'connectionType': 'data-lake', 'name': 'data-lake'}
+        ]
 
         self._service = BaseOnboardingService(
             _SAMPLE_CONFIG,
@@ -68,7 +70,7 @@ class BaseOnboardingTest(TestCase):
             job_types=job_types,
             job_limits=job_limits,
             warehouse_type=DATA_LAKE_WAREHOUSE_TYPE,
-            warehouse_name=None,
+            warehouse_name=connection_type,
             validation_query=validation_query,
             validation_response=validation_response,
             **{}
@@ -122,7 +124,7 @@ class BaseOnboardingTest(TestCase):
             connection_type=connection_type,
             job_types=job_types,
             warehouse_type=DATA_LAKE_WAREHOUSE_TYPE,
-            warehouse_name=None,
+            warehouse_name=connection_type,
             validation_query=validation_query,
             validation_response=validation_response,
             **{}
@@ -304,12 +306,19 @@ class BaseOnboardingTest(TestCase):
             user_service=self._user_service_mock
         )
         self._request_wrapper_mock.make_request_v2.return_value = MonolithResponse(data={'connection': {'uuid': conn_id}})
-        self.assertTrue(service._add_connection(key, OnboardingConfiguration(connection_type=_SAMPLE_CONNECTION_PATH, **{})))
+        self.assertTrue(service._add_connection(key, OnboardingConfiguration(
+            connection_type='glue', warehouse_name='data-lake', **{}
+        )))
 
         self._request_wrapper_mock.make_request_v2.assert_called_once_with(
             query=ADD_CONNECTION_MUTATION,
             operation='addConnection',
-            variables={'key': key, 'connectionType': _SAMPLE_CONNECTION_PATH, 'createWarehouseType': 'data-lake'}
+            variables={
+                'key': key,
+                'connectionType': 'glue',
+                'createWarehouseType': 'data-lake',
+                'name': 'data-lake'
+            }
         )
 
     def test_connection_with_multiple_warehouses(self):
@@ -340,12 +349,14 @@ class BaseOnboardingTest(TestCase):
     def test_connection_with_multiple_warehouses_and_a_lake(self):
         key, conn_id, dw_id = 'foo', 'bar', '456'
         self._user_service_mock.warehouses = [
-            {'uuid': '123', 'connectionType': 'redshift'},
-            {'uuid': dw_id, 'connectionType': 'data-lake'}
+            {'uuid': '123', 'connectionType': 'redshift', 'name': 'redshift'},
+            {'uuid': dw_id, 'connectionType': 'data-lake', 'name': 'data-lake'}
         ]
 
         self._request_wrapper_mock.make_request_v2.return_value = MonolithResponse(data={'connection': {'uuid': conn_id}})
-        self.assertTrue(self._service._add_connection(key, OnboardingConfiguration(connection_type=_SAMPLE_CONNECTION_PATH, **{})))
+        self.assertTrue(self._service._add_connection(key, OnboardingConfiguration(
+            connection_type=_SAMPLE_CONNECTION_PATH, warehouse_name='data-lake', **{}
+        )))
 
         self._request_wrapper_mock.make_request_v2.assert_called_once_with(
             query=ADD_CONNECTION_MUTATION,
@@ -353,7 +364,8 @@ class BaseOnboardingTest(TestCase):
             variables={
                 'key': key,
                 'connectionType': _SAMPLE_CONNECTION_PATH,
-                'dwId': dw_id
+                'dwId': dw_id,
+                'name': 'data-lake'
             }
         )
 
