@@ -35,6 +35,7 @@ class ReportOnboardingTest(TestCase):
             validation_response='testTableauCredentials',
             connection_response='addBiConnection',
             connection_type='tableau',
+            warehouse_type='tableau',
             **_SAMPLE_BASE_OPTIONS
         )
 
@@ -47,6 +48,7 @@ class ReportOnboardingTest(TestCase):
             validation_response='testLookerCredentials',
             connection_response='addBiConnection',
             connection_type='looker',
+            warehouse_type='looker',
             **_SAMPLE_BASE_OPTIONS
         )
 
@@ -69,5 +71,6 @@ class ReportOnboardingTest(TestCase):
             validation_response='testLookerGitCloneCredentials',
             connection_response='addBiConnection',
             connection_type='looker-git-clone',
+            warehouse_type='looker',
             **expected_options
         )
